from django.conf import settings
from django.contrib.auth import get_user_model
from django.contrib.sites.models import Site
from django.core.management.base import BaseCommand
from django.utils import translation

from ...notifications import AccountDeletedNotification

User = get_user_model()


class Command(BaseCommand):
    def handle(self, *args, **options):
        translation.activate(settings.LANGUAGE_CODE)
        users = User.objects.users_to_delete()
        site = Site.objects.get_current()
        AccountDeletedNotification(user=None, site=site, users=users).notify()
        users.delete()



from django.apps import AppConfig


class UserDeletionConfig(AppConfig):
    name = 'user_deletion'

    # users are notificed after 12 months of inactivity
    MONTH_NOTIFICATION = 12
    # users are deleted after 13 months
    MONTH_DELETION = 13



from django.conf import settings
from django.core.mail import send_mass_mail
from django.template.loader import render_to_string
from django.utils.translation import ugettext_lazy as _
from pigeon.notification import Notification


def build_emails(notification):
    context = {'site': notification.site}
    for user in notification.users:
        message = render_to_string(notification.template_name, context)
        yield [
            notification.subject,
            message,
            settings.DEFAULT_FROM_EMAIL,
            [user.email],
        ]


def send_emails(notification):
    messages = build_emails(notification)
    send_mass_mail(messages)


class AccountInactiveNotification(Notification):
    handlers = (send_emails,)
    template_name = 'user_deletion/email_notification.txt'
    subject = _('Re-activate your account')


class AccountDeletedNotification(Notification):
    handlers = (send_emails,)
    template_name = 'user_deletion/email_deletion.txt'
    subject = _('Your account has been deleted')



from setuptools import find_packages, setup


version = '0.1.2'


setup(
    name='django-user-deletion',
    packages=find_packages(),
    include_package_data=True,
    version=version,
    license='BSD',
    description='Management commands to notify and delete inactive django users',
    classifiers=[
        'Development Status :: 1 - Planning',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    author='Incuna Ltd',
    author_email='admin@incuna.com',
    url='https://github.com/incuna/django-user-deletion',
)
